API Reference
=============

This section contains the complete API documentation for HBAT.

Core Modules
------------

.. toctree::
   :maxdepth: 2
   
   core/index

Command Line Interface
----------------------

.. toctree::
   :maxdepth: 2
   
   cli/index

Graphical User Interface
------------------------

.. toctree::
   :maxdepth: 2
   
   gui/index

Constants and Utilities
-----------------------

.. toctree::
   :maxdepth: 2
   
   constants

API Usage Examples
------------------

.. toctree::
   :maxdepth: 2
   
   examples/index